package com.zehong.system.service.impl;

import java.util.List;
import com.zehong.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zehong.system.mapper.TSerialNumberInfoMapper;
import com.zehong.system.domain.TSerialNumberInfo;
import com.zehong.system.service.ITSerialNumberInfoService;

/**
 * 序列号Service业务层处理
 * 
 * @author zehong
 * @date 2024-06-07
 */
@Service
public class TSerialNumberInfoServiceImpl implements ITSerialNumberInfoService 
{
    @Autowired
    private TSerialNumberInfoMapper tSerialNumberInfoMapper;

    /**
     * 查询序列号
     * 
     * @param numberId 序列号ID
     * @return 序列号
     */
    @Override
    public TSerialNumberInfo selectTSerialNumberInfoById(Long numberId)
    {
        return tSerialNumberInfoMapper.selectTSerialNumberInfoById(numberId);
    }

    /**
     * 查询序列号列表
     * 
     * @param tSerialNumberInfo 序列号
     * @return 序列号
     */
    @Override
    public List<TSerialNumberInfo> selectTSerialNumberInfoList(TSerialNumberInfo tSerialNumberInfo)
    {
        return tSerialNumberInfoMapper.selectTSerialNumberInfoList(tSerialNumberInfo);
    }

    /**
     * 新增序列号
     * 
     * @param tSerialNumberInfo 序列号
     * @return 结果
     */
    @Override
    public int insertTSerialNumberInfo(TSerialNumberInfo tSerialNumberInfo)
    {
        return tSerialNumberInfoMapper.insertTSerialNumberInfo(tSerialNumberInfo);
    }

    /**
     * 修改序列号
     * 
     * @param tSerialNumberInfo 序列号
     * @return 结果
     */
    @Override
    public int updateTSerialNumberInfo(TSerialNumberInfo tSerialNumberInfo)
    {
        tSerialNumberInfo.setUpdateTime(DateUtils.getNowDate());
        return tSerialNumberInfoMapper.updateTSerialNumberInfo(tSerialNumberInfo);
    }

    /**
     * 批量删除序列号
     * 
     * @param numberIds 需要删除的序列号ID
     * @return 结果
     */
    @Override
    public int deleteTSerialNumberInfoByIds(Long[] numberIds)
    {
        return tSerialNumberInfoMapper.deleteTSerialNumberInfoByIds(numberIds);
    }

    /**
     * 删除序列号信息
     * 
     * @param numberId 序列号ID
     * @return 结果
     */
    @Override
    public int deleteTSerialNumberInfoById(Long numberId)
    {
        return tSerialNumberInfoMapper.deleteTSerialNumberInfoById(numberId);
    }
}
